@@ -50,9 +50,9 @@ static ClutterBackendEGL *backend_singleton = NULL;
 static const gchar *clutter_fb_device = NULL;
 
 #ifdef COGL_HAS_X11_SUPPORT
-G_DEFINE_TYPE (ClutterBackendEGL, clutter_backend_egl, CLUTTER_TYPE_BACKEND_X11);
+G_DEFINE_TYPE (ClutterBackendEGL, _clutter_backend_egl, CLUTTER_TYPE_BACKEND_X11);
 #else
-G_DEFINE_TYPE (ClutterBackendEGL, clutter_backend_egl, CLUTTER_TYPE_BACKEND);
+G_DEFINE_TYPE (ClutterBackendEGL, _clutter_backend_egl, CLUTTER_TYPE_BACKEND);
 #endif
 
 static void
@@ -69,7 +69,7 @@ clutter_backend_egl_pre_parse (ClutterBackend  *backend,
   const gchar *env_string;
 #ifdef COGL_HAS_X11_SUPPORT
   ClutterBackendClass *backend_x11_class =
-    CLUTTER_BACKEND_CLASS (clutter_backend_egl_parent_class);
+    CLUTTER_BACKEND_CLASS (_clutter_backend_egl_parent_class);
 
   if (!backend_x11_class->pre_parse (backend, error))
     return FALSE;
@@ -90,7 +90,7 @@ clutter_backend_egl_post_parse (ClutterBackend  *backend,
 #ifdef COGL_HAS_X11_SUPPORT
   ClutterBackendX11 *backend_x11 = CLUTTER_BACKEND_X11 (backend);
   ClutterBackendClass *backend_x11_class =
-    CLUTTER_BACKEND_CLASS (clutter_backend_egl_parent_class);
+    CLUTTER_BACKEND_CLASS (_clutter_backend_egl_parent_class);
 #endif
   EGLBoolean status;
 
@@ -147,15 +147,18 @@ clutter_backend_egl_create_context (ClutterBackend  *backend,
     /* NB: This must be the first attribute, since we may
      * try and fallback to no stencil buffer */
     EGL_STENCIL_SIZE,    2,
-
+#ifndef MAEMO
     EGL_RED_SIZE,        1,
     EGL_GREEN_SIZE,      1,
     EGL_BLUE_SIZE,       1,
-    EGL_ALPHA_SIZE,      EGL_DONT_CARE,
+    EGL_BUFFER_SIZE,     EGL_DONT_CARE,
+#else
 
+   EGL_BUFFER_SIZE,    16,
+#endif
+    EGL_ALPHA_SIZE,    EGL_DONT_CARE,
     EGL_DEPTH_SIZE,      1,
 
-    EGL_BUFFER_SIZE,     EGL_DONT_CARE,
 
 #if defined (HAVE_COGL_GL)
     EGL_RENDERABLE_TYPE, EGL_OPENGL_BIT,
@@ -398,7 +401,7 @@ clutter_backend_egl_ensure_context (ClutterBackend *backend,
   ClutterStageWindow *impl;
 
   if (stage == NULL ||
-      (CLUTTER_PRIVATE_FLAGS (stage) & CLUTTER_ACTOR_IN_DESTRUCTION) ||
+      CLUTTER_ACTOR_IN_DESTRUCTION (stage) ||
       ((impl = _clutter_stage_get_window (stage)) == NULL))
     {
       CLUTTER_NOTE (BACKEND, "Clearing EGL context");
@@ -475,7 +478,7 @@ clutter_backend_egl_redraw (ClutterBackend *backend,
 
   g_assert (CLUTTER_IS_STAGE_EGL (impl));
 
-  clutter_stage_egl_redraw (CLUTTER_STAGE_EGL (impl), stage);
+  _clutter_stage_egl_redraw (CLUTTER_STAGE_EGL (impl), stage);
 }
 
 #ifdef HAVE_TSLIB
@@ -493,7 +496,7 @@ clutter_backend_egl_finalize (GObject *gobject)
   if (backend_singleton)
     backend_singleton = NULL;
 
-  G_OBJECT_CLASS (clutter_backend_egl_parent_class)->finalize (gobject);
+  G_OBJECT_CLASS (_clutter_backend_egl_parent_class)->finalize (gobject);
 }
 
 static void
@@ -510,7 +513,7 @@ clutter_backend_egl_dispose (GObject *gobject)
      ClutterBackendX11 will destroy all of the stages before we
      destroy the egl context. Otherwise the actors may try to make GL
      calls during destruction which causes a crash */
-  G_OBJECT_CLASS (clutter_backend_egl_parent_class)->dispose (gobject);
+  G_OBJECT_CLASS (_clutter_backend_egl_parent_class)->dispose (gobject);
 
 #ifdef HAVE_TSLIB
   /* XXX: This should be renamed to _clutter_events_tslib_uninit */
@@ -583,7 +586,7 @@ clutter_backend_egl_constructor (GType                  gtype,
 
   if (!backend_singleton)
     {
-      parent_class = G_OBJECT_CLASS (clutter_backend_egl_parent_class);
+      parent_class = G_OBJECT_CLASS (_clutter_backend_egl_parent_class);
       retval = parent_class->constructor (gtype, n_params, params);
 
       backend_singleton = CLUTTER_BACKEND_EGL (retval);
@@ -733,7 +736,7 @@ clutter_backend_egl_get_visual_info (ClutterBackendX11 *backend_x11)
 #endif
 
 static void
-clutter_backend_egl_class_init (ClutterBackendEGLClass *klass)
+_clutter_backend_egl_class_init (ClutterBackendEGLClass *klass)
 {
   GObjectClass *gobject_class = G_OBJECT_CLASS (klass);
   ClutterBackendClass *backend_class = CLUTTER_BACKEND_CLASS (klass);
@@ -762,10 +765,9 @@ clutter_backend_egl_class_init (ClutterBackendEGLClass *klass)
 }
 
 static void
-clutter_backend_egl_init (ClutterBackendEGL *backend_egl)
+_clutter_backend_egl_init (ClutterBackendEGL *backend_egl)
 {
 #ifndef COGL_HAS_XLIB_SUPPORT
-  ClutterBackend *backend = CLUTTER_BACKEND (backend_egl);
 
 #ifdef HAVE_TSLIB
   backend_egl->event_timer = g_timer_new ();
@@ -781,11 +783,13 @@ clutter_backend_egl_init (ClutterBackendEGL *backend_egl)
 #endif
 }
 
+#ifdef CLUTTER_EGL_BACKEND_GENERIC
 GType
 _clutter_backend_impl_get_type (void)
 {
-  return clutter_backend_egl_get_type ();
+  return _clutter_backend_egl_get_type ();
 }
+#endif
 
 #ifdef COGL_HAS_XLIB_SUPPORT
 EGLDisplay
